Changelog
=========

1.0.0rc2 (2016-04-08)
---------------------

- Improved PyPI page.  [maurits]


1.0.0rc1 (2016-04-08)
---------------------

- Support quintagroup.seoptimizer if it is installed and enabled.  We
  use its title, description and canonical url when set.  [maurits]


1.0.0b1 (2016-03-21)
--------------------

- prevent generating duplicate image tags
  [diederik]

- Documentation
  [diederik]

- Handle images and leadimages correctly.
  [jladage]

- Initial release
  [diederik]
